changeset 1440:8c27b145955a

* keyboard.h (this_command_keys): Extern declaration changed. Doc fix.
author Jim Blandy <jimb@redhat.com>
date Mon, 19 Oct 1992 18:39:37 +0000
parents b3b2d1181d3a
children 929409595312
files src/keyboard.h
diffstat 1 files changed, 6 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/keyboard.h	Mon Oct 19 18:38:58 1992 +0000
+++ b/src/keyboard.h	Mon Oct 19 18:39:37 1992 +0000
@@ -30,9 +30,12 @@
    Initialized by the terminal-specific lisp files.  */
 extern Lisp_Object Vfunction_key_map;
 
-/* Buffer holding the key that invoked the current command.  */
-extern Lisp_Object *this_command_keys;
-extern int this_command_key_count;	/* Size in use.  */
+/* Vector holding the key sequence that invoked the current command.
+   It is reused for each command, and it may be longer than the current
+   sequence; this_command_key_count indicates how many elements
+   actually mean something.  */
+extern Lisp_Object this_command_keys;
+extern int this_command_key_count;
 
 
 /* Macros for dealing with lispy events.  */